@@ -44,7 +44,7 @@ inode()
 	if (argcnt > optind) {
 		if (!full) prhead_inode();
 		for (i = optind; i < argcnt; i++) {
-			addr = getaddr(args[i]);
+			addr = getvalue(args[i]);
 			if (full) prhead_inode();
 			addr = print_inode(addr, full);
 		}
@@ -89,7 +89,7 @@ address_space()
 	for (i = optind; i < argcnt; i++) {
 		if (i > optind)
 			mprintf("\n");
-		addr = getaddr(args[i]);
+		addr = getvalue(args[i]);
 		print_address_space(addr, plist);
 	}
 	return 0;
