@@ -9,6 +9,7 @@ extern const commandtable_t
 	command_block_device,
 	command_buffer_head,
 	command_char_device,
+	command_exception_table,
 	command_ext2_inode_info,
 	command_fib_table,
 	command_file,
@@ -53,6 +54,7 @@ extern const commandtable_t
 	command_vg,
 	command_vm_area_struct,
 	command_vm_struct,
+	command_wait_queue_head,
 	command_zone;
 
 const commandtable_t *commandtable_vers[] = {
@@ -65,6 +67,7 @@ const commandtable_t *commandtable_vers[] = {
 #if SUBLEVEL>=5
 	&command_char_device,
 #endif
+	&command_exception_table,
 	&command_ext2_inode_info,
 	&command_fib_table,
 	&command_file,
@@ -123,6 +126,7 @@ const commandtable_t *commandtable_vers[] = {
 #endif
 	&command_vm_area_struct,
 	&command_vm_struct,
+	&command_wait_queue_head,
 	&command_zone,
 };
 const int ncmdtable_vers = LENGTHOF(commandtable_vers);
