@@ -23,7 +23,7 @@ mprint_dev_t(dev)
 void
 prhead_dentry()
 {
-	mprintf(SPTR" CNT "SPTR" "SPTR" HLCSA "SPTR" "SPTR" VF NAME\n",
+	mprintf(SPTR" CNT "SPTR" "SPTR" HLCSA "SPTR" "SPTR" FL NAME\n",
 		"ADDR", "INODE", "PARENT", "D_OP", "SB");
 }
 
@@ -62,7 +62,7 @@ print_dentry(addr, sw, subdir, parent)
 		(de.d_child.next  !=&((struct dentry *)addr)->d_child  )? 'C': '-',
 		(de.d_subdirs.next!=&((struct dentry *)addr)->d_subdirs)? 'S': '-',
 		(de.d_alias.next  !=&((struct dentry *)addr)->d_alias  )? 'A': '-');
-	mprintf(FPTR " " FPTR " %2lx ", de.d_op, de.d_sb, de.d_vfs_flags);
+	mprintf(FPTR " " FPTR " %2x ", de.d_op, de.d_sb, de.d_flags);
 
 	if (de.d_name.name == ((struct dentry *)addr)->d_iname)
 		mprintstr(de.d_iname, sizeof(de.d_iname));
@@ -489,8 +489,16 @@ print_address_space(addr, plist)
 	mprintf("nrpages:      %8lx\n", as.nrpages);
 	mprintf("ops:          " FPTR "\n", as.a_ops);
 	mprintf("host:         " FPTR "\n", as.host);
+#ifdef _address_space_has_i_mmap_writable	/* >= 2.6.7 */
+	mprintf("mmap:         " FPTR "  %x\n", as.i_mmap.prio_tree_node,
+				as.i_mmap.index_bits);
+	mprintf("mmap_writable:%x\n", as.i_mmap_writable);
+	mprintf("mmap_nonlinear:" FPTR "\n", as.i_mmap_nonlinear.next);
+#endif
+#ifdef _address_space_has_i_mmap_shared		/* < 2.6.7 */
 	mprintf("mmap:         " FPTR "\n", as.i_mmap.next);
 	mprintf("mmap_shared:  " FPTR "\n", as.i_mmap_shared.next);
+#endif
 	mprintf("gfp_mask:    ");
 	mprintbit(asflags, as.flags & ~__GFP_BITS_MASK);
 	print_gfp(as.flags & __GFP_BITS_MASK);
