@@ -7,14 +7,20 @@
 #define __KERNEL__
 #include <linux/mm.h>
 
+#include "flags_page-flags.h"
 #include "flags_mm.h"
 #include "flags_gfp.h"
 
 void
 prhead_page()
 {
+#ifdef _page_has_mapcount
+	mprintf(SPTR" CNT "SPTR"   INDEX MAPC  PRIVATE FLAGS\n",
+		"ADDR", "MAPPING");
+#else
 	mprintf(SPTR" CNT "SPTR"   INDEX "SPTR"  PRIVATE FLAGS\n",
 		"ADDR", "MAPPING", "PTE");
+#endif
 }
 
 int sizeof_page = sizeof(struct page);
@@ -32,9 +38,17 @@ print_page(addr, lru)
 	mprintf(FPTR " ", addr);
 	memread(addr, sizeof(pg), &pg, "page");
 
-	mprintf("%3x " FPTR " %7lx",
-		ATOMIC_READ(pg.count), pg.mapping, pg.index);
+#ifdef _page_has__count
+	mprintf("%3x ", ATOMIC_READ(pg._count));
+#else
+	mprintf("%3x ", ATOMIC_READ(pg.count));
+#endif /*_page_has__count*/
+	mprintf(FPTR " %7lx", pg.mapping, pg.index);
+#ifdef _page_has_mapcount
+	mprintf(" %4x", pg.mapcount);
+#else
 	mprintf(" " FPTR, pg.pte.direct);
+#endif
 	mprintf(" %8lx", pg.private);
 #if defined(WANT_PAGE_VIRTUAL)
 	mprintf(" " FPTR, pg.virtual);
@@ -113,7 +127,9 @@ print_vm_area_struct(addr, full)
 	mprintf("vm_flags:      ");
 	mprintbit(vmflags, vma.vm_flags);
 	mprintf("\n");
+#if 0 /*XXX <=2.6.5 */
 	mprintf("shared:         " FPTR "\n", vma.shared.next);
+#endif
 	mprintf("vm_ops:         " FPTR "\n", vma.vm_ops);
 	mprintf("vm_pgoff:       " FPTR "\n", vma.vm_pgoff);
 	mprintf("vm_file:        " FPTR "\n", vma.vm_file);
