@@ -283,14 +283,20 @@ print_usb_interface(addr, full)
 		mprintf(FPTR " ", addr);
 		mprintf(FPTR " ", ui.altsetting);
 		mprintf("%3x ", ui.num_altsetting);
-		mprintf(FPTR " %3x\n", ui.driver, ui.minor);
+#ifdef _usb_interface_has_driver
+		mprintf(FPTR " ", ui.driver);
+#endif
+		mprintf("%3x\n", ui.minor);
 		return 0;
 	}
 
 	mprintf("addr           " FPTR "\n", addr);
 	mprintf("altsetting     " FPTR "\n", ui.altsetting);
 	mprintf("num_altsetting %x\n", ui.num_altsetting);
+#ifdef _usb_interface_has_driver
 	mprintf("driver         " FPTR "  (usb_driver)\n", ui.driver);
+#endif
 	mprintf("minor          %x\n", ui.minor);
+	mprintf("class_dev      " FPTR "\n", ui.class_dev);
 	return 0;
 }
