@@ -39,6 +39,9 @@ PRIVATE const char *file_op[] = {
 	"open", "flush", "release", "fsync", "aio_fsync", "fasync", "lock",
 	"readv", "writev",
 	"sendfile", "sendpage", "get_unmapped_area",
+#if _file_operations_has_fcntl
+	"fcntl",
+#endif
 	NULL
 };
 
