@@ -19,10 +19,10 @@ translate_addr(addr, count, errmsg)
 {
 	if (addr < kmem_low) {
 		/* user space, not work... */
-		THROWF("Error: V-P translation error: %lx", addr);
-	} else if (addr >= (high_memory? high_memory: kmem_high)) {
+		THROWF("Error: V-P translation error(low): %lx", addr);
+	} else if (addr >= (high_memory > kmem_high? high_memory: kmem_high)) {
 		/* not work... */
-		THROWF("Error: V-P translation error: %lx", addr);
+		THROWF("Error: V-P translation error(high): %lx", addr);
 	}
 	/* global address */
 	return addr - kmem_low;
