@@ -51,6 +51,9 @@ PRIVATE void run_commands();
 
 char *symname;
 char *physname;
+#ifdef CONF_USE_LKCD
+char *kerntype;
+#endif /*CONF_USE_LKCD*/
 
 int quiet = 0;
 int noprompt = 0;
@@ -798,6 +801,13 @@ char *argv[];
 	}
 	if (argc > optind) {
 		symname = argv[optind];
+		if (argc > optind + 1) {
+#ifdef CONF_USE_LKCD
+			kerntype = argv[optind + 1];
+#else
+			usage_abort(argv[0]);
+#endif /*CONF_USE_LKCD*/
+		}
 	}
 
 	TRY {
