@@ -193,6 +193,7 @@ init_sym()
 	char buf[256];
 	int i, hash;
 	addr_t swapper_pg_dir = 0;
+	addr_t end_addr = 0;
 
 	if (symname == NULL) {
 		symname = "/boot/System.map";
@@ -220,12 +221,24 @@ init_sym()
 		if (buf[0] == '.')
 			continue;
 #endif /*0*/
+#ifdef ARCH_i386
 		if (strcmp(buf, "swapper_pg_dir") == 0)
 			swapper_pg_dir = addr;
+#endif
+#ifdef ARCH_x86_64
+		if (strcmp(buf, "init_level4_pgt") == 0)
+			swapper_pg_dir = addr;
+#endif
 #if LINUXVER >= 25
 		/* for 2.5 system_call() */
 		if (strcmp(buf, "syscall_call") == 0)
 			continue;
+#endif
+#if 1
+		if (strcmp(buf, "_end") == 0)
+			end_addr = addr;
+		else if (end_addr == addr)
+			continue;
 #endif
 		addsym(buf, addr, type);
 	}
@@ -436,6 +449,10 @@ searchsym_byaddr(addr)
 		return NULL;
 #endif
 	cached = min;
+#if 1
+	if (addr - symtable[min].addr > 4*1024*1024)
+		return NULL;
+#endif
 	if (symtable[min].addr == kmem_high && addr != kmem_high)
 		return NULL;	/* between static-linked and module address */
 	return &symtable[min];
