@@ -130,7 +130,9 @@ print_xlog_in_core(addr)
 	mprintf(FPTR " " FPTR " " FPTR " ",
 		xic.ic_bp, xic.ic_log, xic.ic_callback);
 	mprintf("%4x %4x %4x %4x %4x ", xic.ic_size, xic.ic_offset, xic.ic_refcnt, xic.ic_roundoff, xic.ic_bwritecnt);
+#ifdef _xlog_in_core_has_hic_data
 	mprintf(FPTR, xic.hic_data);
+#endif /*_xlog_in_core_has_hic_data*/
 	mprintbit(state, xic.ic_state);
 	mprintf("\n");
 #else
@@ -149,8 +151,10 @@ print_xlog_in_core(addr)
 	mprintbit(state, xic.ic_state);
 	mprintf("\n");
 
+#ifdef _xlog_in_core_has_hic_data
 	mprintf("data     " FPTR "\n", xic.hic_data);
-#endif
+#endif /*_xlog_in_core_has_hic_data*/
+#endif /*1*/
 
 	return (addr_t)xic.ic_next;
 }
