@@ -14,6 +14,7 @@ extern addr_t print_xfs_log_item();
 PRIVATE addr_t xfs_trans();
 const commandtable_t command_xfs_trans =
 	{"xfs_trans", xfs_trans, "address", "[XFS] print xfs_trans_t table"};
+extern void prhead_xfs_trans();
 extern addr_t print_xfs_trans();
 
 PRIVATE addr_t
@@ -56,17 +57,27 @@ xfs_trans()
 {
 	int i, c;
 	addr_t addr;
+	int aflag = 0;
 
-	while ((c = getopt(argcnt, args, "")) != EOF) {
+	while ((c = getopt(argcnt, args, "a")) != EOF) {
 		switch (c) {
+		case 'a':
+			aflag = 1;
+			break;
 		default:
 			THROW(usage);
 		}
 	}
 
 	if (argcnt > optind) {
+		if (aflag) {
+			prhead_xfs_trans();
+		}
 		for (i = optind; i < argcnt; i++) {
-			addr = print_xfs_trans(getvalue(args[i]));
+			addr = getvalue(args[i]);
+			do {
+				addr = print_xfs_trans(addr, aflag);
+			} while (aflag && addr);
 		}
 	} else {
 		THROW(usage);
